Function biodivine_lib_param_bn::sbml::import::create_regulations
source · [−]fn create_regulations(
rg: &mut RegulatoryGraph,
transitions: &[SbmlTransition],
id_to_var: &HashMap<String, String>
) -> Result<(), String>Expand description
(internal) Add regulations to a RegulatoryGraph based on the collection
of SBMLTransitions.
Monotonicity is inferred from the sign property of the transition. Observability is
added if the MathML formula in the transition contains the input variable.